@@ -10,19 +10,24 @@
 #  License for the specific language governing permissions and limitations
 #  under the License.
 
+import argparse
 import weakref
 
 from unittest import mock
 
+from cliff.formatters import base as base_formatters
 from cliff import show
 from cliff.tests import base
 
 
-class FauxFormatter:
+class FauxFormatter(base_formatters.SingleFormatter):
     def __init__(self):
         self.args = []
         self.obj = weakref.proxy(self)
 
+    def add_argument_group(self, parser: argparse.ArgumentParser) -> None:
+        return None
+
     def emit_one(self, columns, data, stdout, args):
         self.args.append((columns, data))
 
@@ -43,7 +48,7 @@ class ExerciseShowOne(show.ShowOne):
 class TestShow(base.TestBase):
     def test_formatter_args(self):
         app = mock.Mock()
-        test_show = ExerciseShowOne(app, [])
+        test_show = ExerciseShowOne(app, None)
 
         parsed_args = mock.Mock()
         parsed_args.columns = ('Col1', 'Col2')
@@ -51,6 +56,7 @@ class TestShow(base.TestBase):
 
         test_show.run(parsed_args)
         f = test_show._formatter_plugins['test']
+        assert isinstance(f, FauxFormatter)
         self.assertEqual(1, len(f.args))
         args = f.args[0]
         self.assertEqual(list(parsed_args.columns), args[0])
@@ -59,14 +65,14 @@ class TestShow(base.TestBase):
 
     def test_dict2columns(self):
         app = mock.Mock()
-        test_show = ExerciseShowOne(app, [])
+        test_show = ExerciseShowOne(app, None)
         d = {'a': 'A', 'b': 'B', 'c': 'C'}
         expected = [('a', 'b', 'c'), ('A', 'B', 'C')]
         actual = list(test_show.dict2columns(d))
         self.assertEqual(expected, actual)
 
     def test_no_exist_column(self):
-        test_show = ExerciseShowOne(mock.Mock(), [])
+        test_show = ExerciseShowOne(mock.Mock(), None)
         parsed_args = mock.Mock()
         parsed_args.columns = ('no_exist_column',)
         parsed_args.formatter = 'test'
